﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Runtime.Serialization;
using HeuristicLab.Common;

namespace HeuristicLab.Services.Hive.Common.DataTransfer {
  [DataContract]
  [Serializable]
  public class LightweightJob : HiveItem {
    [DataMember]
    public Guid? SlaveId { get; set; }
    [DataMember]
    public JobState JobState { get; set; }
    [DataMember]
    public TimeSpan? ExecutionTime { get; set; }
    [DataMember]
    public String Exception { get; set; }
    [DataMember]
    public DateTime DateCreated { get; set; }
    [DataMember]
    public DateTime? DateCalculated { get; set; }
    [DataMember]
    public DateTime? DateFinished { get; set; }
    [DataMember]
    public Guid? ParentJobId { get; set; }

    public LightweightJob() {
      JobState = DataTransfer.JobState.Offline;
    }
    public LightweightJob(Job job) {
      this.SlaveId = job.SlaveId;
      this.JobState = job.JobState;
      this.ExecutionTime = job.ExecutionTime;
      this.Exception = job.Exception;
      this.DateCreated = job.DateCreated;
      this.DateCalculated = job.DateCalculated;
      this.DateFinished = job.DateFinished;
      this.ParentJobId = job.ParentJobId;
    }
    protected LightweightJob(LightweightJob original, Cloner cloner) : base(original, cloner) {
      this.SlaveId = original.SlaveId;
      this.JobState = original.JobState;
      this.ExecutionTime = original.ExecutionTime;
      this.Exception = original.Exception;
      this.DateCreated = original.DateCreated;
      this.DateCalculated = original.DateCalculated;
      this.DateFinished = original.DateFinished;
      this.ParentJobId = original.ParentJobId;
    }
    public override IDeepCloneable Clone(Cloner cloner) {
      return new LightweightJob(this, cloner);
    }
  }
}
